@@ -24,7 +24,7 @@ import os
 from storm.databases.postgres import (
     Postgres, compile, currval, Returning, PostgresTimeoutTracer)
 from storm.database import create_database
-from storm.exceptions import ProgrammingError
+from storm.exceptions import InterfaceError, ProgrammingError
 from storm.variables import DateTimeVariable, RawStrVariable
 from storm.variables import ListVariable, IntVariable, Variable
 from storm.properties import Int
@@ -267,35 +267,35 @@ class PostgresTest(DatabaseTest, TestHelper):
 
     def test_case_default_like(self):
 
-        like = Like(SQLRaw("description"), "%hullah%")
+        like = Like(SQLRaw("description"), u"%hullah%")
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(1,)])
 
-        like = Like(SQLRaw("description"), "%HULLAH%")
+        like = Like(SQLRaw("description"), u"%HULLAH%")
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(2,)])
 
     def test_case_sensitive_like(self):
 
-        like = Like(SQLRaw("description"), "%hullah%", case_sensitive=True)
+        like = Like(SQLRaw("description"), u"%hullah%", case_sensitive=True)
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(1,)])
 
-        like = Like(SQLRaw("description"), "%HULLAH%", case_sensitive=True)
+        like = Like(SQLRaw("description"), u"%HULLAH%", case_sensitive=True)
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(2,)])
 
     def test_case_insensitive_like(self):
 
-        like = Like(SQLRaw("description"), "%hullah%", case_sensitive=False)
+        like = Like(SQLRaw("description"), u"%hullah%", case_sensitive=False)
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(1,), (2,)])
-        like = Like(SQLRaw("description"), "%HULLAH%", case_sensitive=False)
+        like = Like(SQLRaw("description"), u"%HULLAH%", case_sensitive=False)
         expr = Select(SQLRaw("id"), like, tables=["like_case_insensitive_test"])
         result = self.connection.execute(expr)
         self.assertEquals(result.get_all(), [(1,), (2,)])
@@ -526,6 +526,21 @@ class PostgresDisconnectionTest(DatabaseDisconnectionTest, TestHelper):
     host_environment_variable = "STORM_POSTGRES_HOST_URI"
     default_port = 5432
 
+    def test_rollback_swallows_InterfaceError(self):
+        """Test that InterfaceErrors get caught on rollback().
+
+        InterfaceErrors are a form of a disconnection error, so rollback()
+        must swallow them and reconnect.
+        """
+        class FakeConnection:
+            def rollback(self):
+                raise InterfaceError('connection already closed')
+        self.connection._raw_connection = FakeConnection()
+        try:
+            self.connection.rollback()
+        except Exception, exc:
+            self.fail('Exception should have been swallowed: %s' % repr(exc))
+
 
 class PostgresTimeoutTracerTest(TimeoutTracerTestBase):
 
@@ -552,7 +567,8 @@ class PostgresTimeoutTracerTest(TimeoutTracerTestBase):
         try:
             self.connection.execute(statement)
         except TimeoutError, e:
-            self.assertEquals(e.statement, statement)
-            self.assertEquals(e.params, ())
+            self.assertEqual("SQL server cancelled statement", e.message)
+            self.assertEqual(statement, e.statement)
+            self.assertEqual((), e.params)
         else:
             self.fail("TimeoutError not raised")
