@@ -67,9 +67,18 @@ class TestHelper(mocker.MockerTestCase):
                 break
         is_supported = getattr(self, "is_supported", None)
         if is_supported is not None and not is_supported():
+            if hasattr(result, "addSkip"):
+                result.startTest(self)
+                result.addSkip(self, "Test not supported")
             return
         unittest.TestCase.run(self, result)
 
+    def assertVariablesEqual(self, checked, expected):
+        self.assertEquals(len(checked), len(expected))
+        for check, expect in zip(checked, expected):
+            self.assertEquals(check.__class__, expect.__class__)
+            self.assertEquals(check.get(), expect.get())
+
 
 class MakePath(object):
 
