@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2006, 2007 Canonical
+# Copyright (c) 2006-2010 Canonical
 #
 # Written by Gustavo Niemeyer <gustavo@niemeyer.net>
 #
@@ -25,7 +25,6 @@ from storm.database import create_database
 from storm.exceptions import NoneError
 from storm.sqlobject import *
 from storm.store import Store
-from storm.expr import Asc, Like
 from storm.tz import tzutc
 
 from tests.helper import TestHelper
@@ -745,6 +744,17 @@ class SQLObjectTest(TestHelper):
         result = self.Person.select()
         self.assertEquals(result.count(), 2)
 
+    def test_result_set_count_limit(self):
+        result = self.Person.select(limit=1)
+        self.assertEquals(len(list(result)), 1)
+        self.assertEquals(result.count(), 1)
+
+    def test_result_set_count_sliced(self):
+        result = self.Person.select()
+        sliced_result = result[1:]
+        self.assertEquals(len(list(sliced_result)), 1)
+        self.assertEquals(sliced_result.count(), 1)
+
     def test_result_set_count_distinct(self):
         result = self.Person.select(
             "person.id = phone.person_id",
@@ -772,11 +782,27 @@ class SQLObjectTest(TestHelper):
         self.assertEquals(list(result.__iter__())[0].name, "John Joe")
 
     def test_result_set__nonzero__(self):
+        """
+        L{SQLObjectResultSet.__nonzero__} returns C{True} if the result set
+        contains results.  If it contains no results, C{False} is
+        returned.
+        """
         result = self.Person.select()
         self.assertEquals(result.__nonzero__(), True)
         result = self.Person.select(self.Person.q.name == "No Person")
         self.assertEquals(result.__nonzero__(), False)
 
+    def test_result_set_is_empty(self):
+        """
+        L{SQLObjectResultSet.is_empty} returns C{True} if the result set
+        doesn't contain any results.  If it does contain results, C{False} is
+        returned.
+        """
+        result = self.Person.select()
+        self.assertEquals(result.is_empty(), False)
+        result = self.Person.select(self.Person.q.name == "No Person")
+        self.assertEquals(result.is_empty(), True)
+
     def test_result_set_distinct(self):
         result = self.Person.select("person.name = 'John Joe'",
                                     clauseTables=["phone"])
