@@ -21,7 +21,14 @@
 from datetime import datetime, date, time, timedelta
 from decimal import Decimal
 import cPickle as pickle
+import gc
+import weakref
+try:
+    import uuid
+except ImportError:
+    uuid = None
 
+from storm.compat import json
 from storm.exceptions import NoneError
 from storm.variables import *
 from storm.event import EventSystem
@@ -91,6 +98,18 @@ class VariableTest(TestHelper):
         variable.set(marker, from_db=True)
         self.assertEquals(variable.sets, [(marker, False), (marker, True)])
 
+    def test_set_leak(self):
+        """When a variable is checkpointed, the value must not leak."""
+        variable = Variable()
+        m = Marker()
+        m_ref = weakref.ref(m)
+        variable.set(m)
+        variable.checkpoint()
+        variable.set(LazyValue())
+        del m
+        gc.collect()
+        self.assertIdentical(m_ref(), None)
+
     def test_get(self):
         variable = CustomVariable()
         variable.set(marker)
@@ -102,10 +121,6 @@ class VariableTest(TestHelper):
         self.assertEquals(variable.get(to_db=True), ("g", ("s", marker)))
         self.assertEquals(variable.gets, [(("s", marker), True)])
 
-    def test_eq(self):
-        self.assertEquals(CustomVariable(marker), CustomVariable(marker))
-        self.assertNotEquals(CustomVariable(marker), CustomVariable(object()))
-
     def test_is_defined(self):
         variable = CustomVariable()
         self.assertFalse(variable.is_defined())
@@ -198,7 +213,7 @@ class VariableTest(TestHelper):
         def changed(owner, variable, old_value, new_value, fromdb):
             changed_values.append((owner, variable,
                                    old_value, new_value, fromdb))
-        
+
         event.hook("changed", changed)
 
         variable = CustomVariable(event=event)
@@ -260,14 +275,9 @@ class VariableTest(TestHelper):
         variable = CustomVariable()
         variable.set(marker)
         variable_copy = variable.copy()
+        variable_copy.gets = []
         self.assertTrue(variable is not variable_copy)
-        self.assertTrue(variable == variable_copy)
-
-    def test_hash(self):
-        # They must hash the same to be used as cache keys.
-        obj1 = CustomVariable(marker)
-        obj2 = CustomVariable(marker)
-        self.assertEquals(hash(obj1), hash(obj2))
+        self.assertVariablesEqual([variable], [variable_copy])
 
     def test_lazy_value_setting(self):
         variable = CustomVariable()
@@ -310,7 +320,7 @@ class VariableTest(TestHelper):
         def changed(owner, variable, old_value, new_value, fromdb):
             changed_values.append((owner, variable,
                                    old_value, new_value, fromdb))
-        
+
         event.hook("changed", changed)
 
         variable = CustomVariable(event=event)
@@ -545,6 +555,7 @@ class DateVariableTest(TestHelper):
         date_str = "1977-05-04"
         date_uni = unicode(date_str)
         date_obj = date(1977, 5, 4)
+        datetime_obj = datetime(1977, 5, 4, 0, 0, 0)
 
         variable = DateVariable()
 
@@ -554,6 +565,8 @@ class DateVariableTest(TestHelper):
         self.assertEquals(variable.get(), date_obj)
         variable.set(date_obj, from_db=True)
         self.assertEquals(variable.get(), date_obj)
+        variable.set(datetime_obj, from_db=True)
+        self.assertEquals(variable.get(), date_obj)
 
         self.assertRaises(TypeError, variable.set, 0, from_db=True)
         self.assertRaises(TypeError, variable.set, marker, from_db=True)
@@ -651,7 +664,7 @@ class TimeDeltaVariableTest(TestHelper):
         self.assertEquals(variable.get(), delta)
 
         self.assertRaises(TypeError, variable.set, marker)
-    
+
     def test_get_set_from_database(self):
         delta_str = "42 days 12:34:56.78"
         delta_uni = unicode(delta_str)
@@ -772,13 +785,57 @@ class ParseIntervalTest(TestHelper):
             self.fail("ValueError not raised")
 
 
-class PickleVariableTest(TestHelper):
+class UUIDVariableTest(TestHelper):
+
+    def is_supported(self):
+        return uuid is not None
+
+    def test_get_set(self):
+        value = uuid.UUID("{0609f76b-878f-4546-baf5-c1b135e8de72}")
+
+        variable = UUIDVariable()
+
+        variable.set(value)
+        self.assertEquals(variable.get(), value)
+        self.assertEquals(
+            variable.get(to_db=True), "0609f76b-878f-4546-baf5-c1b135e8de72")
+
+        self.assertRaises(TypeError, variable.set, marker)
+        self.assertRaises(TypeError, variable.set,
+                          "0609f76b-878f-4546-baf5-c1b135e8de72")
+        self.assertRaises(TypeError, variable.set,
+                          u"0609f76b-878f-4546-baf5-c1b135e8de72")
+
+    def test_get_set_from_database(self):
+        value = uuid.UUID("{0609f76b-878f-4546-baf5-c1b135e8de72}")
+
+        variable = UUIDVariable()
+
+        # Strings and UUID objects are accepted from the database.
+        variable.set(value, from_db=True)
+        self.assertEquals(variable.get(), value)
+        variable.set("0609f76b-878f-4546-baf5-c1b135e8de72", from_db=True)
+        self.assertEquals(variable.get(), value)
+        variable.set(u"0609f76b-878f-4546-baf5-c1b135e8de72", from_db=True)
+        self.assertEquals(variable.get(), value)
+
+        # Some other representations for UUID values.
+        variable.set("{0609f76b-878f-4546-baf5-c1b135e8de72}", from_db=True)
+        self.assertEquals(variable.get(), value)
+        variable.set("0609f76b878f4546baf5c1b135e8de72", from_db=True)
+        self.assertEquals(variable.get(), value)
+
+
+class EncodedValueVariableTestMixin(object):
+
+    encoding = None
+    variable_type = None
 
     def test_get_set(self):
         d = {"a": 1}
-        d_dump = pickle.dumps(d, -1)
+        d_dump = self.encode(d)
 
-        variable = PickleVariable()
+        variable = self.variable_type()
 
         variable.set(d)
         self.assertEquals(variable.get(), d)
@@ -789,7 +846,7 @@ class PickleVariableTest(TestHelper):
         self.assertEquals(variable.get(to_db=True), d_dump)
 
         self.assertEquals(variable.get_state(), (Undef, d_dump))
-        
+
         variable.set(marker)
         variable.set_state((Undef, d_dump))
         self.assertEquals(variable.get(), d)
@@ -800,12 +857,13 @@ class PickleVariableTest(TestHelper):
     def test_pickle_events(self):
         event = EventSystem(marker)
 
-        variable = PickleVariable(event=event, value_factory=list)
+        variable = self.variable_type(event=event, value_factory=list)
 
         changes = []
         def changed(owner, variable, old_value, new_value, fromdb):
             changes.append((variable, old_value, new_value, fromdb))
 
+        event.emit("start-tracking-changes", event)
         event.hook("changed", changed)
 
         variable.checkpoint()
@@ -833,23 +891,57 @@ class PickleVariableTest(TestHelper):
         self.assertEquals(changes, [(variable, None, ["a"], False)])
 
 
+class PickleVariableTest(EncodedValueVariableTestMixin, TestHelper):
+
+    encode = staticmethod(lambda data: pickle.dumps(data, -1))
+    variable_type = PickleVariable
+
+
+class JSONVariableTest(EncodedValueVariableTestMixin, TestHelper):
+
+    encode = staticmethod(lambda data: json.dumps(data).decode("utf-8"))
+    variable_type = JSONVariable
+
+    def is_supported(self):
+        return json is not None
+
+    def test_unicode_from_db_required(self):
+        # JSONVariable._loads() complains loudly if it does not receive a
+        # unicode string because it has no way of knowing its encoding.
+        variable = self.variable_type()
+        self.assertRaises(TypeError, variable.set, '"abc"', from_db=True)
+
+    def test_unicode_to_db(self):
+        # JSONVariable._dumps() works around unicode/str handling issues in
+        # simplejson/json.
+        variable = self.variable_type()
+        variable.set({u"a": 1})
+        self.assertTrue(isinstance(variable.get(to_db=True), unicode))
+
+
 class ListVariableTest(TestHelper):
 
     def test_get_set(self):
-        l = [1, 2]
-        l_dump = pickle.dumps(l, -1)
+        # Enumeration variables are used as items so that database
+        # side and python side values can be distinguished.
+        get_map = {1: "a", 2: "b", 3: "c"}
+        set_map = {"a": 1, "b": 2, "c": 3}
+        item_factory = VariableFactory(
+            EnumVariable, get_map=get_map, set_map=set_map)
 
-        variable = ListVariable(IntVariable)
+        l = ["a", "b"]
+        l_dump = pickle.dumps(l, -1)
+        l_vars = [item_factory(value=x) for x in l]
+
+        variable = ListVariable(item_factory)
 
         variable.set(l)
         self.assertEquals(variable.get(), l)
-        self.assertEquals(variable.get(to_db=True),
-                          [IntVariable(1), IntVariable(2)])
+        self.assertVariablesEqual(variable.get(to_db=True), l_vars)
 
-        variable.set([1.1, 2.2], from_db=True)
+        variable.set([1, 2], from_db=True)
         self.assertEquals(variable.get(), l)
-        self.assertEquals(variable.get(to_db=True),
-                          [IntVariable(1), IntVariable(2)])
+        self.assertVariablesEqual(variable.get(to_db=True), l_vars)
 
         self.assertEquals(variable.get_state(), (Undef, l_dump))
 
@@ -857,8 +949,8 @@ class ListVariableTest(TestHelper):
         variable.set_state((Undef, l_dump))
         self.assertEquals(variable.get(), l)
 
-        variable.get().append(3)
-        self.assertEquals(variable.get(), [1, 2, 3])
+        variable.get().append("c")
+        self.assertEquals(variable.get(), ["a", "b", "c"])
 
     def test_list_events(self):
         event = EventSystem(marker)
@@ -870,6 +962,7 @@ class ListVariableTest(TestHelper):
         def changed(owner, variable, old_value, new_value, fromdb):
             changes.append((variable, old_value, new_value, fromdb))
 
+        event.emit("start-tracking-changes", event)
         event.hook("changed", changed)
 
         variable.checkpoint()
